-- 
-- Manager OOB (out-of-box) default users and roles tables:
--
--  MGR_OOB_USER      -- OOB users
--  MGR_OOB_ROLE      -- OOB roles
--  MGR_OOB_USER_ROLE -- Intersection table for users and their roles
--
CREATE TABLE MGR_OOB_USER (
    USERID      INTEGER         NOT NULL,
    USERNAME    VARCHAR(64)     NOT NULL,
    PASSWORD    VARCHAR(64)     NOT NULL,
    CONSTRAINT PK_USERID PRIMARY KEY (USERID)
);

CREATE TABLE MGR_OOB_ROLE (
    ROLEID      INTEGER         NOT NULL,
    ROLENAME    VARCHAR(64)     NOT NULL,
    CONSTRAINT PK_ROLEID PRIMARY KEY (ROLEID) 
);

CREATE TABLE MGR_OOB_USER_ROLE (
    USERID      INTEGER         NOT NULL,
    ROLEID      INTEGER         NOT NULL,
    ROLENAME    VARCHAR(64)     NOT NULL,
    CONSTRAINT PK_OOB_USER_ROLE  PRIMARY KEY (USERID,ROLEID),
    CONSTRAINT FK_ROLEID FOREIGN KEY (ROLEID) REFERENCES MGR_OOB_ROLE(ROLEID),
    CONSTRAINT FK_USERID FOREIGN KEY (USERID) REFERENCES MGR_OOB_USER(USERID)
);

INSERT INTO MGR_OOB_USER values (0,'admin','admin');
INSERT INTO MGR_OOB_USER values (1,'requester','optim');
INSERT INTO MGR_OOB_USER values (2,'reviewer','optim');
INSERT INTO MGR_OOB_USER values (3,'designer','optim');
INSERT INTO MGR_OOB_USER values (4,'operator','optim');
INSERT INTO MGR_OOB_ROLE values(0,'admin');
INSERT INTO MGR_OOB_ROLE values(1,'requester');
INSERT INTO MGR_OOB_ROLE values(2,'reviewer');
INSERT INTO MGR_OOB_ROLE values(3,'designer');
INSERT INTO MGR_OOB_ROLE values(4,'operator');
INSERT INTO MGR_OOB_USER_ROLE values(0,0,'admin');
INSERT INTO MGR_OOB_USER_ROLE values(1,1,'requester');
INSERT INTO MGR_OOB_USER_ROLE values(2,2,'reviewer');
INSERT INTO MGR_OOB_USER_ROLE values(3,3,'designer');
INSERT INTO MGR_OOB_USER_ROLE values(4,4,'operator');


-- 
-- Manager group management tables and indexes:
--
--  MGR_GROUPS        -- Groups
--  MGR_GROUP_SERVICE -- Intersection table for groups and their services
--  MGR_GROUP_FOLDER  -- Intersection table for groups and their folders
--
CREATE SEQUENCE MGR_GROUPS_SEQUENCE;
CREATE TABLE MGR_GROUPS (
    GROUP_ID        NUMBER (10, 0)       NOT NULL,
    NAME            VARCHAR2(100)   NOT NULL,
    DESCRIPTION     VARCHAR2(1024),
    CONSTRAINT PK_GROUPS PRIMARY KEY (GROUP_ID) 
);

CREATE UNIQUE INDEX UQ_GROUP_NAME ON MGR_GROUPS(NAME);

CREATE TABLE MGR_GROUP_SERVICE (
    GROUP_ID        INTEGER         NOT NULL,
    SERVICE_ID      CHAR(36)        NOT NULL,
    CONSTRAINT PK_GROUP_SERVICE PRIMARY KEY (GROUP_ID, SERVICE_ID),
    CONSTRAINT FK_GROUP_SERVICE FOREIGN KEY (GROUP_ID) REFERENCES MGR_GROUPS(GROUP_ID) 
);

CREATE TABLE MGR_GROUP_FOLDER (
    GROUP_ID        INTEGER         NOT NULL,
    FOLDER_ID       CHAR(36)        NOT NULL,
    CONSTRAINT PK_GROUP_FOLDER PRIMARY KEY (GROUP_ID, FOLDER_ID),
    CONSTRAINT FK_GROUP_FOLDER FOREIGN KEY (GROUP_ID) REFERENCES MGR_GROUPS(GROUP_ID) 
);


--
-- Manager user management tables:
--
--  MGR_USER_GROUP -- Intersection table for users and their groups
--  MGR_USER_ROLE  -- Intersection table for users and their roles
--
CREATE TABLE MGR_USER_GROUP (
    USER_NAME   VARCHAR(100)    NOT NULL,        
    GROUP_ID    INTEGER         NOT NULL,      
    CONSTRAINT PK_GROUP_USER PRIMARY KEY (USER_NAME, GROUP_ID),
    CONSTRAINT FK_GROUP_USER FOREIGN KEY (GROUP_ID) REFERENCES MGR_GROUPS(GROUP_ID) ON DELETE CASCADE 
);

CREATE TABLE MGR_USER_ROLE (
    USER_NAME   VARCHAR(100)    NOT NULL,
    ROLEID      INTEGER         NOT NULL,
    CONSTRAINT PK_USER_ROLE PRIMARY KEY (USER_NAME, ROLEID),
    CONSTRAINT FK_USER_ROLE FOREIGN KEY (ROLEID) REFERENCES MGR_OOB_ROLE(ROLEID) 
);


--
-- Manager preferences table(s):
--
--  MGR_GLOBAL_PREFERENCES -- Preferences global for all users
--  MGR_USER_PREFERENCES   -- Preferences specific for a single user
--
CREATE SEQUENCE MGR_GLOBAL_PREF_SEQUENCE;
CREATE TABLE MGR_GLOBAL_PREFERENCES (
    GLOBAL_PREFERENCES_ID   NUMBER (10, 0)       NOT NULL,
    REPOSITORY_LOCATION     VARCHAR(128)    NOT NULL,
    LOG_LEVEL               VARCHAR(64)     NOT NULL,
    TEMP_DIR_LOCATION       VARCHAR(128)    NOT NULL,
    CONSOLE_REFRESH_TIME    INTEGER         NOT NULL,
    MESSAGE_REFRESH_TIME    INTEGER         NOT NULL,
    ACTION_TIMEOUT_TIME     INTEGER         NOT NULL,
    FIRST_TIME_ADMIN        CHAR (1)        DEFAULT 't' NOT NULL,               
    SERVER_SSL              INTEGER         DEFAULT 0 NOT NULL,        
    ENABLE_SERVICE_GROUPS   CHAR (1)        DEFAULT 'f' NOT NULL, 
    CONSTRAINT PK_PREFERENCES PRIMARY KEY (GLOBAL_PREFERENCES_ID) 
);

INSERT INTO MGR_GLOBAL_PREFERENCES 
    (GLOBAL_PREFERENCES_ID, REPOSITORY_LOCATION, LOG_LEVEL, TEMP_DIR_LOCATION, CONSOLE_REFRESH_TIME, MESSAGE_REFRESH_TIME, ACTION_TIMEOUT_TIME)
    values (MGR_GLOBAL_PREF_SEQUENCE.NEXTVAL, 'http://localhost:8088', 'Warning', '/temp', 300, 60, 120);

CREATE SEQUENCE MGR_USER_PREF_SEQUENCE;
CREATE TABLE MGR_USER_PREFERENCES (
    USER_PREFERENCES_ID     NUMBER (10, 0)       NOT NULL,
    USERNAME                VARCHAR(64)     NOT NULL,
    CONSOLE_REFRESH_TIME    INTEGER         NOT NULL,
    MESSAGE_REFRESH_TIME    INTEGER         NOT NULL,
    ACTION_TIMEOUT          INTEGER         NOT NULL,
    LAST_RUN_JOB_QUERY_ID   INTEGER,
    CONSTRAINT PK_USER_PREFERENCES_ID PRIMARY KEY (USER_PREFERENCES_ID)   
);


--
-- Manager (and Bridge) service assignement table:
--
--  MGR_SERVICE_ASSIGNMENT -- Proxy assignement for each service
--
CREATE TABLE MGR_SERVICE_ASSIGNMENT (
    service_id              CHAR(36)        NOT NULL,
    is_automatic_proxy      CHAR (1)        DEFAULT 'f' NOT NULL,
    proxy_uri               VARCHAR2(512),
    env_type                CHAR(2)         NOT NULL,
    CONSTRAINT PK_SERVICE_ASSIGNMENT PRIMARY KEY (service_id, env_type)
);


--
-- Dynamic configuration table:
--
--  MGR_CONFIGURATION -- Dynamic configuration information for each environment (i.e., EM, SM)
--
CREATE TABLE MGR_CONFIGURATION (
    MANAGER_CONFIGURATION_ID    CHAR(36)    NOT NULL,
    ENVIRONMENT                 INTEGER     NOT NULL,
    CONFIGURATION_DEFAULT       CLOB,
    CONFIGURATION_MODIFIED      CLOB,
    CONSTRAINT PK_MANAGER_CONFIGURATION PRIMARY KEY (MANAGER_CONFIGURATION_ID)
);


--
-- Manager access control list table:
--
--  MGR_ACL -- Default and modified access control list information 
-- 
CREATE TABLE MGR_ACL (
    MANAGER_ACL_ID  CHAR(36) NOT NULL,
    ACL_DEFAULT     CLOB,
    ACL_MODIFIED    CLOB,
    CONSTRAINT PK_MANAGER_ACL PRIMARY KEY (MANAGER_ACL_ID) 
);
--
-- Manager service instance options table:
--  MGR_SERVICE_INSTANCE_OPTIONS -- For storing overrides and other attributes for each service execution
--
CREATE TABLE MGR_SERVICE_INSTANCE_OPTIONS(
        INSTANCE_ID CHAR(36) NOT NULL,
        OPTIONS BLOB,
        CONSTRAINT service_instance_pk PRIMARY KEY (INSTANCE_ID)
);


--
-- Manager service overrides table:
--
--  MGR_SERVICE_OVERRIDES -- Override information for each service
--
CREATE TABLE MGR_SERVICE_OVERRIDES (
    SERVICE_ID  CHAR(36) NOT NULL,
    OVERRIDES   BLOB,
    CONSTRAINT service_overrides_pk PRIMARY KEY (SERVICE_ID)
);


--
-- Manager service set tables:
--
--  MGR_SERVICESET      -- Service set information
--  MGR_SERVICESET_INSTANCE -- Service set execution results
--  MGR_SERVICE_INSTANCES_IN_SET  -- Intersection table to contain the services in each service set execution
--  

CREATE TABLE MGR_SERVICESET (
    NAME                    VARCHAR2(256)   NOT NULL,
    VERSION                 VARCHAR(25),
    IS_STOP_ON_FAILURE      CHAR (1)         DEFAULT 'f',
    CONTENT                 BLOB,
    CONSTRAINT em_serviceset_pk PRIMARY KEY (NAME, VERSION)
);

CREATE TABLE MGR_SERVICESET_INSTANCE (
    ID                      CHAR(36)        NOT NULL,    
    NAME                    VARCHAR2(256)   NOT NULL,
    VERSION                 VARCHAR(25)     NOT NULL,
    IS_STOP_ON_FAILURE      CHAR (1)         DEFAULT 'f',
    ORIGIN                  VARCHAR(64)     NOT NULL,
    EXECUTED_BY             VARCHAR(64)     NOT NULL,
    CONSTRAINT PK_SERVICESET PRIMARY KEY (ID)
);

--
-- Manager (and Bridge) scheduler tables and indexes:  
--
--  mgr_schedules       -- Schedule informtion
--  mgr_scheduler_tasks -- Schedule taskIntersection table to contain the services in each set
--  mgr_triggers        -- Service set (container) information for the embedded manager
-- 
create table mgr_schedules (
    id              char(36)    not null,
    entity_version  integer,
    constraint schedules_pk primary key (id)
);

create table mgr_scheduler_tasks (
    id                      char(36)        not null,
    scheduler_task_type     char(13)        not null,
    service_id              varchar(254)    not null,
    proxy_url               varchar(254),
    entity_version          integer,
    creator                 varchar(64),
    origin                  varchar(64),
    constraint scheduler_tasks_pk primary key (id),
    constraint scheduler_tasks_fk foreign key (id) references mgr_schedules (id)
);
    
create table mgr_triggers (
    id                  char(36)    not null,
    trigger_type        char(7)     not null,
    start_date          NUMBER(20,0)      not null,
    end_date            NUMBER(20,0)      not null,
    cron_expression     varchar(254),
    repeat_count        integer,
    repeat_interval     NUMBER(20,0),
    entity_version      integer,
    constraint triggers_pk primary key (id),
    constraint triggers_fk foreign key (id) references mgr_schedules (id)
);
    
create index i_schdtsk_dtype on mgr_scheduler_tasks (scheduler_task_type);

create index i_trigger_dtype on mgr_triggers (trigger_type);


--
-- Manager filtering tables and indexes:  
--
--  MGR_JOB_QUERY   -- Service monitoring job (i.e., service instance) query 
-- 
CREATE SEQUENCE MGR_JOB_QUERY_SEQUENCE;
CREATE TABLE MGR_JOB_QUERY (
    JOB_QUERY_ID            NUMBER (10, 0)       NOT NULL,
    ENV_TYPE                CHAR(2)         NOT NULL,
    JOB_QUERY_NAME          VARCHAR(64)     NOT NULL,
    USER_NAME               VARCHAR(64)     NOT NULL,
    SERVICE_PATH            VARCHAR(128),
    JOB_STATUS              VARCHAR(64),
    MGMT_CANONICAL_NAME     VARCHAR2(256),
    START_DATE_RANGE        VARCHAR(64),
    START_DATE_TIME         VARCHAR(64),
    END_DATE_TIME           VARCHAR(64),
    SERVICE_TYPE            VARCHAR(128),
    SERVICE_REQUEST_TYPE    VARCHAR(128),
    CONSTRAINT PK_JOB_QUERY PRIMARY KEY (JOB_QUERY_ID) 
);

CREATE UNIQUE INDEX UQ_JOB_QUERY_NAME ON MGR_JOB_QUERY (JOB_QUERY_NAME, ENV_TYPE, USER_NAME);


--
-- Manager (and Bridge) service instance and artifacts tables:  
--
--  mgr_service_instances          -- Service instance information 
--  mgr_artifact_type              -- Artifact types
--  mgr_artifacts                  -- Service instance artifacts
--  mgr_service_instance_artifacts -- Artifacts for each service instance 
-- 
create table mgr_service_instances (
    id                  char(36)        not null,
    service_name        varchar(254)    not null,
    service_version     varchar(25)     not null,
    platform_type       varchar(128)    not null,
    request_type        varchar(128)    not null,
    start_time          NUMBER(20,0),
    end_time            NUMBER(20,0),
    has_ended           CHAR (1)         default 'f',
    return_code         integer,
    abend_code          integer,
    jes_job_name        varchar(254),
    jcl_error           CHAR (1)         default 'f',
    restart_retry       CHAR (1)         default 'f',
    proxy_url           VARCHAR2(512),
    service_id          char(36),
    executed_by         varchar(64)     not null,
    origin              varchar(64)     not null, 
    control_file_path   varchar(254),
    folder_path         varchar(254),
    constraint service_instances_pk primary key (id)
);

create table mgr_artifact_type ( 
    id                  char(36)        not null,
    name                varchar(254)    not null,
    constraint artifact_type_pk primary key (id)
);

create table mgr_artifacts (
    id                  char(36)        not null,
    name                varchar(254)    not null,
    content             blob            not null,
    type_id             char(36)        not null,
    constraint artifacts_pk primary key (id),
    constraint artifacts_type_fk foreign key (type_id) references mgr_artifact_type (id)
);

create table mgr_service_instance_artifacts (
    service_execution_id    char(36)    not null,
    artifact_id             char(36)    not null,
    constraint service_instance_artifacts_pk primary key (service_execution_id, artifact_id),
    constraint service_instance_artifacts_fk1 foreign key (service_execution_id) references mgr_service_instances (id),
    constraint service_instance_artifacts_fk2 foreign key (artifact_id) references mgr_artifacts (id)
);

create table mgr_restart_retry_history (
    service_execution_id   char(36)        not null,
    parent_execution_id    char(36),
    control_file_path      varchar(254),
    constraint mgr_restart_retry_history_pk primary key (service_execution_id),
    constraint mgr_restart_retry_history_fk1 foreign key (service_execution_id) references mgr_service_instances (id)
);

CREATE TABLE MGR_SERVICE_INSTANCES_IN_SET (
    SERVICESET_ID           CHAR(36)        NOT NULL,
    SERVICE_INSTANCE_ID     CHAR(36)        NOT NULL,
    SERVICE_NAME            VARCHAR2 (256)  NOT NULL,
    MANAGED_SERVICE_STATUS  VARCHAR(64),
    SERVICE_TYPE            VARCHAR(128),
    REQUEST_TYPE            VARCHAR(128),
    CONSTRAINT PK_SERVICES_IN_SET PRIMARY KEY (SERVICESET_ID, SERVICE_INSTANCE_ID),
    CONSTRAINT FK_SERVICES_IN_SET FOREIGN KEY (SERVICESET_ID) REFERENCES MGR_SERVICESET_INSTANCE(ID),
    CONSTRAINT FK_SERVICE_INSTANCE_ID FOREIGN KEY (SERVICE_INSTANCE_ID) REFERENCES MGR_SERVICE_INSTANCES(ID)
);


insert into mgr_artifact_type (id, name) values ('1', 'Log');
insert into mgr_artifact_type (id, name) values ('2', 'Properties');
insert into mgr_artifact_type (id, name) values ('3', 'JCL');
insert into mgr_artifact_type (id, name) values ('4', 'Request');
insert into mgr_artifact_type (id, name) values ('5', 'Response');
insert into mgr_artifact_type (id, name) values ('6', 'Overrides');
insert into mgr_artifact_type (id, name) values ('7', 'Other');

-- 
-- Manager Work Order Tables:
--
--  MGR_WO_WORKFLOW		  -- Work Order Work Flow Templates
--  MGR_WO_STATES         -- Work Order States
--  MGR_WO_TRANSITIONS    -- Work Order Transitions
--  MGR_WO_NOTIFICATIONS  -- Work Order Notifications
--  MGR_USER_EMAILS       -- User emails
--  MGR_WORK_ORDERS       -- Work Orders
--  MGR_WO_EXEC_INSTANCES -- Work Order Execution Instances
--  MGR_WO_SEARCH_VW      -- Work Order Search View
--

CREATE TABLE MGR_WO_WORKFLOW (
    ID          INTEGER         NOT NULL,
    NAME        VARCHAR(32)     NOT NULL,
    DESCRIPTION VARCHAR(255),
    CONSTRAINT PK_WO_WORKFLOW PRIMARY KEY (ID)
);

INSERT INTO MGR_WO_WORKFLOW values (1, 'DEFAULT', 'The default work order work flow template.');

CREATE TABLE MGR_WO_STATES (
    ID           INTEGER         NOT NULL,
    WF_ID		 INTEGER			NOT NULL,
    STATE        VARCHAR(32)     NOT NULL,
    OWNER        INTEGER			NOT NULL,
    ACTIVE       VARCHAR(1)		NOT NULL,
    NOTIFY		 VARCHAR(1)		NOT NULL,
    CONFIGURABLE VARCHAR(1)		NOT NULL,
    CONSTRAINT PK_WO_STATES PRIMARY KEY (ID, WF_ID),
    CONSTRAINT FK_STATES_WF FOREIGN KEY (WF_ID) REFERENCES MGR_WO_WORKFLOW(ID),
    CONSTRAINT FK_STATES_OWNER FOREIGN KEY (OWNER) REFERENCES MGR_OOB_ROLE(ROLEID)
);

INSERT INTO MGR_WO_STATES values (100, 1, 'NEW', 1, 'Y', 'N', 'N');
INSERT INTO MGR_WO_STATES values (200, 1, 'REQUESTED', 2, 'Y', 'Y', 'Y');
INSERT INTO MGR_WO_STATES values (250, 1, 'DENIED', 1, 'Y', 'Y', 'N');
INSERT INTO MGR_WO_STATES values (300, 1, 'QUEUED', 3, 'Y', 'Y', 'N');
INSERT INTO MGR_WO_STATES values (400, 1, 'SUBMITTED', 3, 'Y', 'Y', 'N');
INSERT INTO MGR_WO_STATES values (450, 1, 'REJECTED', 2, 'Y', 'Y', 'N');
INSERT INTO MGR_WO_STATES values (500, 1, 'READY', 1, 'Y', 'Y', 'N');
INSERT INTO MGR_WO_STATES values (550, 1, 'RETURNED', 3, 'Y', 'Y', 'N');
INSERT INTO MGR_WO_STATES values (600, 1, 'COMPLETED', 1, 'Y', 'Y', 'N');
INSERT INTO MGR_WO_STATES values (999, 1, 'TERMINATED', 1, 'Y', 'Y', 'N');

CREATE TABLE MGR_WO_TRANSITIONS (
    ID		 	 INTEGER		NOT NULL,
    WF_ID		 INTEGER		NOT NULL,
    STATE_ID     INTEGER		NOT NULL,
    NEW_STATE_ID INTEGER		NOT NULL,
    TRANSITION   VARCHAR(32)	NOT NULL,
    OWNER        INTEGER		NOT NULL,
    ACTIVE       VARCHAR(1)		NOT NULL,
    CONSTRAINT PK_WO_TRANSITIONS PRIMARY KEY  (ID, WF_ID),
    CONSTRAINT FK_STATES FOREIGN KEY  (STATE_ID, WF_ID)     REFERENCES MGR_WO_STATES(ID, WF_ID),
    CONSTRAINT FK_NEW_STATES FOREIGN KEY  (NEW_STATE_ID, WF_ID) REFERENCES MGR_WO_STATES(ID, WF_ID),
    CONSTRAINT FK_TRANSITION_OWNER FOREIGN KEY  (OWNER) REFERENCES MGR_OOB_ROLE(ROLEID)
);

INSERT INTO MGR_WO_TRANSITIONS values (1, 1, 100, 200, 'SUBMIT', 1, 'Y');
INSERT INTO MGR_WO_TRANSITIONS values (2, 1, 200, 250, 'DENY', 2, 'Y');
INSERT INTO MGR_WO_TRANSITIONS values (3, 1, 250, 200, 'RESUBMIT', 1, 'Y');
INSERT INTO MGR_WO_TRANSITIONS values (4, 1, 200, 999, 'TERMINATE', 1, 'Y');
INSERT INTO MGR_WO_TRANSITIONS values (5, 1, 200, 999, 'TERMINATE', 2, 'Y');
INSERT INTO MGR_WO_TRANSITIONS values (6, 1, 200, 999, 'TERMINATE', 3, 'Y');
INSERT INTO MGR_WO_TRANSITIONS values (7, 1, 250, 999, 'TERMINATE', 1, 'Y');
INSERT INTO MGR_WO_TRANSITIONS values (8, 1, 250, 999, 'TERMINATE', 2, 'Y');
INSERT INTO MGR_WO_TRANSITIONS values (9, 1, 250, 999, 'TERMINATE', 3, 'Y');
INSERT INTO MGR_WO_TRANSITIONS values (10, 1, 200, 300, 'APPROVE', 2, 'Y');
INSERT INTO MGR_WO_TRANSITIONS values (11, 1, 100, 300, 'SUBMIT', 1, 'N');
INSERT INTO MGR_WO_TRANSITIONS values (12, 1, 300, 999, 'TERMINATE', 1, 'Y');
INSERT INTO MGR_WO_TRANSITIONS values (13, 1, 300, 999, 'TERMINATE', 2, 'Y');
INSERT INTO MGR_WO_TRANSITIONS values (14, 1, 300, 999, 'TERMINATE', 3, 'Y');
INSERT INTO MGR_WO_TRANSITIONS values (15, 1, 300, 400, 'ACCEPT', 3, 'Y');
INSERT INTO MGR_WO_TRANSITIONS values (16, 1, 400, 450, 'REJECT', 3, 'Y');
INSERT INTO MGR_WO_TRANSITIONS values (17, 1, 450, 300, 'RESUBMIT', 2, 'Y');
INSERT INTO MGR_WO_TRANSITIONS values (18, 1, 400, 999, 'TERMINATE', 1, 'Y');
INSERT INTO MGR_WO_TRANSITIONS values (19, 1, 400, 999, 'TERMINATE', 2, 'Y');
INSERT INTO MGR_WO_TRANSITIONS values (20, 1, 400, 999, 'TERMINATE', 3, 'Y');
INSERT INTO MGR_WO_TRANSITIONS values (21, 1, 450, 999, 'TERMINATE', 1, 'Y');
INSERT INTO MGR_WO_TRANSITIONS values (22, 1, 450, 999, 'TERMINATE', 2, 'Y');
INSERT INTO MGR_WO_TRANSITIONS values (23, 1, 450, 999, 'TERMINATE', 3, 'Y');
INSERT INTO MGR_WO_TRANSITIONS values (24, 1, 400, 500, 'ASSOCIATE', 3, 'Y');
INSERT INTO MGR_WO_TRANSITIONS values (25, 1, 400, 600, 'COMPLETE', 3, 'Y');
INSERT INTO MGR_WO_TRANSITIONS values (26, 1, 500, 550, 'RETURN', 1, 'Y');
INSERT INTO MGR_WO_TRANSITIONS values (27, 1, 550, 500, 'RESUBMIT', 3, 'Y');
INSERT INTO MGR_WO_TRANSITIONS values (28, 1, 500, 999, 'TERMINATE', 1, 'Y');
INSERT INTO MGR_WO_TRANSITIONS values (29, 1, 500, 999, 'TERMINATE', 2, 'Y');
INSERT INTO MGR_WO_TRANSITIONS values (30, 1, 500, 999, 'TERMINATE', 3, 'Y');
INSERT INTO MGR_WO_TRANSITIONS values (31, 1, 550, 999, 'TERMINATE', 1, 'Y');
INSERT INTO MGR_WO_TRANSITIONS values (32, 1, 550, 999, 'TERMINATE', 2, 'Y');
INSERT INTO MGR_WO_TRANSITIONS values (33, 1, 550, 999, 'TERMINATE', 3, 'Y');

CREATE TABLE MGR_WO_NOTIFICATIONS (
    STATE_ID	INTEGER	NOT NULL,
    WF_ID		INTEGER NOT NULL,
    NOTIFY_ID	INTEGER	NOT NULL,
    CONSTRAINT PK_WO_NOTIFICATIONS PRIMARY KEY  (STATE_ID, WF_ID, NOTIFY_ID),
    CONSTRAINT FK_NOTIFY_STATES FOREIGN KEY  (STATE_ID, WF_ID) REFERENCES MGR_WO_STATES(ID, WF_ID),
    CONSTRAINT FK_NOTIFY FOREIGN KEY  (NOTIFY_ID) REFERENCES MGR_OOB_ROLE(ROLEID)
);

INSERT INTO MGR_WO_NOTIFICATIONS values (200, 1, 2);
INSERT INTO MGR_WO_NOTIFICATIONS values (250, 1, 1);
INSERT INTO MGR_WO_NOTIFICATIONS values (300, 1, 3);
INSERT INTO MGR_WO_NOTIFICATIONS values (400, 1, 1);
INSERT INTO MGR_WO_NOTIFICATIONS values (450, 1, 1);
INSERT INTO MGR_WO_NOTIFICATIONS values (450, 1, 2);
INSERT INTO MGR_WO_NOTIFICATIONS values (500, 1, 1);
INSERT INTO MGR_WO_NOTIFICATIONS values (550, 1, 3);
INSERT INTO MGR_WO_NOTIFICATIONS values (600, 1, 1);
INSERT INTO MGR_WO_NOTIFICATIONS values (999, 1, 1);

CREATE TABLE MGR_USER_EMAILS (
    USERNAME    VARCHAR(100)     NOT NULL,
    EMAIL_ADDR	VARCHAR(255),
    CONSTRAINT PK_USERNAME PRIMARY KEY (USERNAME)
);
CREATE SEQUENCE MGR_WORK_ORDERS_SEQUENCE;
CREATE TABLE MGR_WORK_ORDERS (
    ID		 	 NUMBER(10, 1)	NOT NULL,
    WF_ID		 INTEGER		NOT NULL,
    STATE_ID     INTEGER		NOT NULL,
    DESCRIPTION	 VARCHAR2(256),
    WO_TYPE	 	 VARCHAR(32),
    PRIORITY     VARCHAR(64),
    COMMENTS     VARCHAR2(4000), -- USED TO BE 16384
    TAGS		 VARCHAR2(4000), -- USED TO BE 4096
    CREATEDBY	 VARCHAR(100)	NOT NULL,
    CREATEDDT	 NUMBER(20,0)			NOT NULL,
    SERVICE_ID	 CHAR(36),
    SS_NAME	 	 VARCHAR2(256),
    SS_VERSION	 VARCHAR(25),
    CONSTRAINT PK_WORK_ORDERS PRIMARY KEY  (ID),
    CONSTRAINT FK_WO_STATES FOREIGN KEY  (STATE_ID, WF_ID)     REFERENCES MGR_WO_STATES(ID, WF_ID),
    CONSTRAINT FK_SERVICES FOREIGN KEY  (SERVICE_ID)	       REFERENCES DD_SERVICES(ID),
    CONSTRAINT FK_SERVICE_SETS FOREIGN KEY  (SS_NAME, SS_VERSION) REFERENCES MGR_SERVICESET(NAME, VERSION)
);

CREATE TABLE MGR_WO_EXEC_INSTANCES (
    WO_ID       	INTEGER      NOT NULL,
    EXECUTION_ID	CHAR(36)     NOT NULL,
    EXEC_TYPE		VARCHAR(32)	 NOT NULL,
    CONSTRAINT PK_EXEC_INSTANCES PRIMARY KEY (WO_ID, EXECUTION_ID, EXEC_TYPE),
    CONSTRAINT FK_WOEI_WORK_ORDERS FOREIGN KEY (WO_ID) REFERENCES MGR_WORK_ORDERS(ID)
);

CREATE VIEW MGR_WO_SEARCH_VW (
ID
,WF_ID
,STATE_ID
,DESCRIPTION
,WO_TYPE
,PRIORITY
,COMMENTS
,TAGS
,CREATEDBY
,CREATEDDT
,SERVICE_ID
,SS_NAME
,SS_VERSION
) AS SELECT 
ID
,WF_ID
,STATE_ID
,LOWER(DESCRIPTION)
,WO_TYPE
,PRIORITY
,LOWER(COMMENTS)
,LOWER(TAGS)
,CREATEDBY
,CREATEDDT
,SERVICE_ID
,SS_NAME
,SS_VERSION
FROM MGR_WORK_ORDERS;